##  Terminology
Please see the chart below for helpful terminology:
Terminology | Definition
---|---
read | To be able to "see", to make visible. For example, this can be defined for a particular attribute and or relation.
create | To be able to associate a response to an attribute, relation, etc that is "null"/empty/not filled out.
delete | To be able to remove/delete information that has been entered AND SAVED against a particular Fact Sheet within a particular attribute, relation, etc. Such as a particular relation, e.g. the Data Objects relation on the Application Fact Sheet type.
update | To be able to edit information that is already existing. For example, the Description of a Fact Sheet reads, "A new version is coming out in 2022". If a user is assigned to an authorization role that has access to update this attribute, they would be able to CHANGE the answer to anything else they wish, such as "A new version is coming out in 2024"


